@@ -4,16 +4,16 @@ use warnings;
 package Printer::Thermal;
 
 # PODNAME: Printer::Thermal
-# ABSTRACT: Interface for Thermal and some dot-matrix and inkjet Printers that support ESC-POS specification (Deprecated) - Use L<Printer::ESCPOS> instead
+# ABSTRACT: Interface for Thermal (and some dot-matrix and inkjet) Printers that support ESC/POS specification.
 #
 # This file is part of Printer-Thermal
 #
-# This software is copyright (c) 2015 by Shantanu Bhadoria.
+# This software is copyright (c) 2013 by Shantanu Bhadoria.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.29'; # VERSION
+our $VERSION = 'v0.3'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -23,7 +23,6 @@ use POSIX;
 use Device::SerialPort;
 use IO::File;
 use IO::Socket;
-use Time::HiRes qw(usleep);
 
 
 has usb_device_path => (
@@ -118,35 +117,30 @@ has print_string => (
     default => '',
 );
 
-
 has font => (
     is      => 'rw',
     isa     => 'Int',
     default => 0,
 );
 
-
 has underline => (
     is      => 'rw',
     isa     => 'Int',
     default => 0,
 );
 
-
 has emphasized => (
     is      => 'rw',
     isa     => 'Int',
     default => 0,
 );
 
-
 has double_height => (
     is      => 'rw',
     isa     => 'Int',
     default => 0,
 );
 
-
 has double_width => (
     is      => 'rw',
     isa     => 'Int',
@@ -196,16 +190,10 @@ sub _build_printer {
 
 
 sub print {
-    my ($self) = @_;
+    my ( $self, $string ) = @_;
     my $printer = $self->printer;
-    my @chunks;
-    my $string = $self->print_string;
-    my $n      = 100;                   # Size of each chunk in bytes
-    @chunks = unpack "a$n" x ( ( length($string) / $n ) - 1 ) . "a*", $string;
-    for my $chunk (@chunks) {
-        $printer->write($chunk);
-        usleep(2000);
-    }
+    print "\nPrinting : " . $self->print_string . "\n";
+    $printer->write( $self->print_string );
     $self->print_string("");
 }
 
@@ -234,7 +222,7 @@ sub reset {
 }
 
 
-sub right_side_character_spacing {
+sub right_side_charachter_spacing {
     my ( $self, $spacing ) = @_;
     if ( $spacing <= 255 && $spacing >= 0 ) {
         $self->write($_ESC);
@@ -293,15 +281,17 @@ sub justify {
 
 sub bold_off {
     my ($self) = @_;
-    $self->emphasized(0);
-    $self->_apply_printmode();
+    $self->write($_ESC);
+    $self->write( chr(69) );
+    $self->write( chr(0) );
 }
 
 
 sub bold_on {
     my ($self) = @_;
-    $self->emphasized(1);
-    $self->_apply_printmode();
+    $self->write($_ESC);
+    $self->write( chr(69) );
+    $self->write( chr(1) );
 }
 
 
@@ -344,7 +334,6 @@ sub font_size {
     $self->write( chr($size) );
 }
 
-
 sub font_size_esc {
     my ( $self, $size ) = @_;
     $self->write($_ESC);
@@ -360,7 +349,7 @@ sub font_b {
     #$self->write(chr(77));
     #$self->write(chr(1));
     $self->font(1);
-    $self->_apply_printmode();
+    $self->apply_printmode();
 }
 
 
@@ -371,10 +360,27 @@ sub font_a {
     #$self->write(chr(77));
     #$self->write(chr(0));
     $self->font(0);
-    $self->_apply_printmode();
+    $self->apply_printmode();
 }
 
-sub _apply_printmode {
+
+sub _printmode {
+    my ( $self, $font_number, $double_height_mode, $double_width_mode ) = @_;
+    if (   ( $font_number eq 1 || $font_number eq 0 )
+        && ( $double_height_mode eq 1 || $double_height_mode eq 0 )
+        && ( $double_width_mode eq 1  || $double_width_mode eq 0 ) )
+    {
+        my $value =
+          $font_number +
+          ( $double_height_mode * 16 ) +
+          ( $double_height_mode * 32 );
+        $self->write($_ESC);
+        $self->write( chr(33) );
+        $self->write( chr($value) );
+    }
+}
+
+sub apply_printmode {
     my ($self)        = @_;
     my $font          = $self->font;
     my $underline     = $self->underline;
@@ -400,7 +406,7 @@ sub underline_off {
     #$self->write(chr(45));
     #$self->write(chr(0));
     $self->underline(0);
-    $self->_apply_printmode();
+    $self->apply_printmode();
 }
 
 
@@ -411,7 +417,7 @@ sub underline_on {
     #$self->write(chr(45));
     #$self->write(chr(1));
     $self->underline(1);
-    $self->_apply_printmode();
+    $self->apply_printmode();
 }
 
 
@@ -462,7 +468,6 @@ sub print_text {
     }
 }
 
-
 sub print_bitmap {
     my ( $self, $pixels, $w, $h, $output_png ) = @_;
     my $counter = 0;
@@ -506,16 +511,6 @@ sub cutpaper {
 }
 
 
-sub open_cash_drawer {
-    my ($self) = @_;
-    $self->write($_ESC);
-    $self->write( chr(112) );
-    $self->write( chr(0) );
-    $self->write( chr(50) );
-    $self->write( chr(250) );
-}
-
-
 sub test {
     my ($self) = @_;
     $self->write("Write Stuff before linefeed");
@@ -529,11 +524,11 @@ sub test {
     #$self->barcode_height(68);
     #$self->print_barcode();
 
-    $self->right_side_character_spacing(1);
+    $self->right_side_charachter_spacing(1);
     $self->write("Rgt chr space: 1 space");
-    $self->right_side_character_spacing(8);
+    $self->right_side_charachter_spacing(8);
     $self->write(" 8 space");
-    $self->right_side_character_spacing(0);
+    $self->right_side_charachter_spacing(0);
     $self->linefeed();
 
     $self->horiz_tab();
@@ -663,9 +658,20 @@ sub test {
     $self->cutpaper();
 
     $self->print();
+    return;
     $self->bold_on();
     $self->print_text("line is bold\n");
     $self->bold_off();
+    $self->printmode( 0, 0, 1 );
+    $self->print_text("Part of this ");
+    $self->printmode( 0, 1, 0 );
+    $self->print_text("Part of this \n");
+    $self->printmode( 0, 0, 0 );
+    $self->print_text("Part of this ");
+    $self->printmode( 1, 0, 0 );
+    $self->print_text("line is fontB\n");
+    $self->printmode( 0, 0, 0 );
+    $self->print_text("Part of this ");
     $self->font_b( 1, 0, 0 );
     $self->print_text("line is fontB\n");
     $self->print_text("Part of this is different font\n");
@@ -700,11 +706,11 @@ sub test {
     $self->print_text("line is Inverted\n");
     $self->inverse_off();
     $self->justify("R");
-    $self->print_text("right justified\r");
+    $self->print_text("right justified\n");
     $self->justify("C");
-    $self->print_text("centered\r");
+    $self->print_text("centered\n");
     $self->justify("L");    # justify("L") works too
-    $self->print_text("left justified\r");
+    $self->print_text("left justified\n");
     $self->linefeed();
     $self->linefeed();
     $self->linefeed();
@@ -761,11 +767,11 @@ __END__
 
 =head1 NAME
 
-Printer::Thermal - Interface for Thermal and some dot-matrix and inkjet Printers that support ESC-POS specification (Deprecated) - Use L<Printer::ESCPOS> instead
+Printer::Thermal - Interface for Thermal (and some dot-matrix and inkjet) Printers that support ESC/POS specification.
 
 =head1 VERSION
 
-version 0.29
+version v0.3
 
 =head1 SYNOPSIS
 
@@ -783,7 +789,7 @@ version 0.29
  
    #For local printer connected on serial port, check syslog(Usually under /var/log/syslog) for what device file was created for your printer when you connect it to your system(For plug and play printers).
    my $path = '/dev/ttyACM0';
-   $printer = Printer::Thermal->new(serial_device_path=$path);
+   $printer2 = Printer::Thermal->new(serial_device_path=$path);
    $printer->write("Blah Blah \nReceipt Details\nFooter");
    $printer->bold_on();
    $printer->write("Bold Text");
@@ -792,7 +798,7 @@ version 0.29
  
    #For local printer connected on usb port, check syslog(Usually under /var/log/syslog) for what device file was created for your printer when you connect it to your system(For plug and play printers).
    my $path = '/dev/usb/lp0';
-   $printer = Printer::Thermal->new(usb_device_path=$path);
+   $printer2 = Printer::Thermal->new(usb_device_path=$path);
    $printer->write("Blah Blah \nReceipt Details\nFooter");
    $printer->bold_on();
    $printer->write("Bold Text");
@@ -801,13 +807,12 @@ version 0.29
 
 =head1 DESCRIPTION
 
-This Module is deprecated in favour of L<Printer::ESCPOS>, which is the shiny new successor to this module. L<Printer::Thermal> will continue to work and might receive occasional support and bug fixes but no new features. Read the See Also section for reasons on why I deprecated L<Printer::Thermal> in favour of a new namespace instead of upgrading the existing module. For those who are already using L<Printer::Thermal>, have simple needs and are happy with what this module provides, they can avoid the switch to L<Printer::ESCPOS> as that module does not have a interface compatible with L<Printer::Thermal> and might involve some work switching over. If you are starting a new project or if you want the support for brand new features like printing logos etc., then you must use L<Printer::ESCPOS>.
-
-For ESC-P codes refer the guide from Epson http:E<sol>E<sol>support.epson.ruE<sol>uploadE<sol>library_fileE<sol>14E<sol>esc-p.pdf
+Some might not find the module name accurate since ESCE<sol>P was developed initially for dot matrix and inkjet printers, however today most Thermal Receipt Printers use these codes for control. Most people(i.e. like me when I started looking for Thermal Printer stuff) who look for Thermal Printer codes don't know Thermal Printers use certain set of ESC codes to achieve a bunch of functions, and I didn't want to name it Printer::ESC::P because that would not help people who are new to receipt printers looking for something like this module. This module provides an Object oriented interface for interacting with Thermal Printers. Maybe I will refactor it later with subclasses. I used Moose, I apologize!! 
+For ESCE<sol>P codes refer the guide from Epson http:E<sol>E<sol>support.epson.ruE<sol>uploadE<sol>library_fileE<sol>14E<sol>esc-p.pdf
 
 =head1 ATTRIBUTES
 
-=head2 usb_device_path
+=head2 $printer->usb_device_path
 
 This variable contains the path for the printer device file when connected as a usb device on UNIX-like systems. I haven't added support for Windows and it probably wont work in doz as a local printer without some modifications. Feel free to try it out and let me know what happens. This must be passed in the constructor
 
@@ -825,11 +830,7 @@ Contains the network port of the device when its a network printer. The module c
 
 =head2 baudrate
 
-When used as a local serial device you can set the baudrate of the printer too. Default (38400) will usually work, but not always. 
-
-This param may be specified when creating printer object to make sure it works properly.
-
-$printer = Printer::Thermal->new(serial_device_path => '/dev/ttyACM0', baudrate => 9600);
+When used as a local serial device you can set the baudrate of the printer too. However default should usually work. let me know if it doesn't for you.
 
 =head2 read_char_time
 
@@ -841,82 +842,48 @@ $printer = Printer::Thermal->new(serial_device_path => '/dev/ttyACM0', baudrate
 
 =head2 black_threshold 
 
-Black ink threshold, This param may be specified when creating the printer object. Default is 48.
+Black ink threshold
 
 =head2 alpha_threshold 
 
-Alpha threshold, This param may be specified when creating the printer object. Default is 127.
+Black alpha threshold
 
 =head2 heatTime
 
-Heating time to set for Supported Thermal Printers, this affects dot intensity.
-
-This param may be specified when creating the printer object. Default is 120
+Heating time to set for Supported Thermal Printers, this affects dot intensity
 
 =head2 heatInterval
 
-This param may be specified when creating the printer object. Default is 50
-
 =head2 heatingDots
 
-This param may be specified when creating the printer object. Default is 7
-
 =head2 printer
 
 This is the direct device handle to the printer, You must almost never use this.
-Unless you are hacking through the module. If you are using this you must send me
-a bug report on why you had to use this.
-
-You can access it with $printer->printer
+Unless you are hacking through the module. If you are using this you should send
+a bug report on why you need to use this.
 
 =head2 print_string
 
-This contains the string in the module buffer that will be sent to the printer when you call $printer->print();
+This contains the string in the module buffer
 
 my $print_string = $printer->print_string
 
-=head2 font
+=head2 $printer->print();
 
-Set ESC-POS Font
-
-=head2 underline
-
-Set/unset underline property
-
-=head2 emphasized
-
-Set/unset emphasized property
-
-=head2 double_height
-
-set unset double height property
-
-=head2 double_width
-
-set unset double width property
-
-=head1 METHODS
-
-=head2 print
-
-$printer->print()
 Sends the accumulated commands to the printer. All commands below need to be followed by a print() to send the data from buffer to the printer. You may call more than one printer command and then call print to send them all to printer together.
 The following bunch of commands print a text to a printer, move down one line, and cut the receipt paper.
+  $printer->write("hello Printer\n");
+  $printer->linefeed();
+  $printer->cutpaper();
+  $pritner->print(); # Sends the all the commands before this to the printer in one go. 
 
-    $printer->write("hello Printer\n");
-    $printer->linefeed();
-    $printer->cutpaper();
-    $printer->print(); # Sends the all the commands before this to the printer in one go. 
+=head2 $printer->write("some text\n");
 
-=head2 write
-
-$printer->write("some text\n")
 Writes a bunch of text that you pass here to the module buffer. 
 Note that this will not be passed to the printer till you call $printer->print()
 
-=head2 left_margin
+=head2 $printer->left_margin($nl,$nh);
 
-$printer->left_margin($nl,$nh)
 Sets the left margin code to the printer. takes two single byte parameters, $nl and $nh.
 To determine the value of these two bytes, use the INT and MOD conventions. INT indicates the integer (or whole number) part of a number, while MOD indicates the
 remainder of a division operation.
@@ -924,149 +891,91 @@ For example, to break the value 520 into two bytes, use the following two equati
 nH = INT 520/256
 nL = MOD 520/256
 
-=head2 reset
+=head2 $printer->reset()
 
 Resets the printer 
 
-=head2 right_side_character_spacing
+=head2 $printer->right_side_charachter_spacing($spacing)
 
 Takes a one byte number, spacing as a parameter
 
-=head2 horiz_tab
+=head2 $printer->horiz_tab()
 
-Adds a horizontal tab character like a \t to the print string.
+=head2 $printer->line_spacing($value)
 
-=head2 line_spacing
+=head2 $printer->linefeed()
 
-Allows you to set the line spacing for the printer.
-
-=head2 linefeed
-
-Sends a new line character, i.e carriage return and line feed
-
-=head2 justify
+=head2 $printer->justify($alignment)
 
 $alignment can be either 'L','C' or 'R' for left center and right justified printing
 
-=head2 bold_off
+=head2 $printer->bold_off();
 
-Turns bold printing off
+=head2 $printer->bold_on();
 
-=head2 bold_on
+=head2 $printer->doublestrike_off();
 
-Turns bold printing on
+=head2 $printer->doublestrike_on();
 
-=head2 doublestrike_off
+=head2 $printer->emphasize_off();
 
-Turns doublestrike on characters off
+=head2 $printer->emphasize_on();
 
-=head2 doublestrike_on
-
-Turns doublestrike on characters on
-
-=head2 emphasize_off
-
-Turns off emphasize(read ESC-POS documentation)
-
-=head2 emphasize_on
-
-Turns on emphasize(read ESC-POS documentation)
-
-=head2 font_size
+=head2 $printer->font_size($n);
 
 Defined Region
-0 <= n <= 255
-However, 1 <= vertical direction magnification ratio <= 8, 1 <= horizontal direction magnification ratio <= 8
+0 ≤ n ≤ 255
+However, 1 ≤ vertical direction magnification ratio ≤ 8, 1 ≤ horizontal direction magnification ratio ≤ 8
 Initial Value n=0
 Function Specifies the character size (magnification ratio in the vertical and horizontal directions).
 
-=head2 font_size_esc
+=head2 $printer->font_b();
 
-Set ESC specified font size
+=head2 $printer->font_a();
 
-    $printer->font_size_esc($size);
+=head2 $printer->printmode($font_number, $double_height_mode, $double_width_mode);
 
-=head2 font_b
+0 or 1,
 
-Switches printing to font b
+=head2 $printer->underline_off();
 
-=head2 font_a
+=head2 $printer->underline_on();
 
-Switches printing to font a
+=head2 $printer->inverse_off();
 
-=head2 underline_off
+=head2 $printer->inverse_on();
 
-Switches off underline
+=head2 $printer->barcode_height($height);
 
-=head2 underline_on
+=head2 $printer->print_barcode($type,$string)
 
-Switches on underline
+=head2 $printer->print_text($msg,$chars_per_line);
 
-=head2 inverse_off
+Print some text defined by msg. If chars_per_line is defined, inserts newlines after the given amount. Use normal '\n' line breaks for empty lines.
 
-Switches off inverse text
-
-=head2 inverse_on
-
-Switches on inverse text
-
-=head2 barcode_height
-
-Sets barcode height
-
-=head2 print_barcode
-
-$printer->print_barcode($type,$string)
-Prints barcode
-
-=head2 print_text
-
-$printer->print_text($msg,$chars_per_line);
-Prints some text defined by msg. If chars_per_line is defined, inserts newlines after the given amount. Use normal '\n' line breaks for empty lines.
-
-=head2 print_bitmap
-
-To be done: This function is not implemented yet.
-
-=head2 color_1
+=head2 $printer->color_1()
 
 Prints in first color for dual color printers
 
-=head2 color_2
+=head2 $printer->color_2()
 
 Prints in second color for dual color printers
 
-=head2 cutpaper
+=head2 $printer->cutpaper()
 
 Cuts the paper. Most Thermal receipt printers support the facility to cut the receipt using this command once printing is done.
 
-=head2 open_cash_drawer
-
-Opens the Cash Drawer connected to the thermal printer.
-
-=head2 test
+=head2 $printer->test()
 
 Prints a bunch of test strings to see if your printer is working fine/connected properly. Don't worry if some things like emphasized and double strike looks the same, it happened with my printer too.
 
-=head1 NOTES
-
-=over
-
-=item *
-
-If the printer prints out garbled characters instead of proper text, try specifying the baudrate parameter when creating printer object when you create the printer object(not for network or USB printers)
-
-=back
-
-     $printer = Printer::Thermal->new(serial_device_path => '/dev/ttyACM0', baudrate => 9600);
-
 =head1 USAGE
 
 =over
 
 =item *
 
-This Module offers a object oriented interface to ESC-POS Printers. 
+This Module offers a object oriented interface to ESCE<sol>POS Printers. 
 
 =item *
 
@@ -1088,25 +997,19 @@ Note: While you may call print() after every single command code, this is not ad
 
 =head1 SEE ALSO
 
-L<Printer::ESCPOS> is the new module that will take over the Perl support for ESC-POS receipt printers. Why did I choose to deprecate L<Printer::Thermal> for L<Printer::ESCPOS> instead of upgrading it? Read on if you are curious
-
 =over
 
 =item *
 
-When I started writing L<Printer::Thermal> I was working with Thermal printers for my own requirements and wanted to write something that would work with all Thermal Printers. As I discovered after a couple of releases of L<Printer::Thermal>, the ESC-POS specification is a broad command specification for POS printers and it has nothing to do with the print technology itself thermal or others, so the name of the module was a big misnomer and it led to lot of confusion as to question of what the module was actually for.
+L<Device::SerialPort>
 
 =item *
 
-L<Printer::Thermal> module was only intended for supporting thermal printers but it worked quiet well with other printer types. The way receipt printers work there was no reason to have a module specifically for thermal printers. So this Printer::Thermal name started to make me uneasy.
+L<IO::File>
 
 =item *
 
-There are those have minimal printing needs from their POS printers, they are already using L<Printer::Thermal> and are happy with it. There is no reason for them to switch over unless they start a new project. For newer users it makes sense to start with a module that will have future supports and adds a wider range of flexible functions for ESC-POS Printers.
-
-=item *
-
-Last but not the least important reason, I wanted to make two things user-expandable: Printer connection(USB, Serial, Network etc.) and Printer Model Profiles(As I discovered that while most printer had more or less common command codes, They all had their own feature sets which borrowed most commands from a subset of ESCPOS. So I wanted users to be able to create their own profiles of supported commands to allow community effort for expansion of module functionality. Adding these two to existing module would have broken backward compatibility. L<Printer::ESCPOS> will have better interfaces for users to add their own connection types and printer profiles.
+L<IO::Socket>
 
 =back
 
@@ -1117,7 +1020,7 @@ Last but not the least important reason, I wanted to make two things user-expand
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests through github at 
-L<https://github.com/shantanubhadoria/perl-printer-thermal/issues>.
+L<https://github.com/shantanubhadoria/printer-thermal/issues>.
 You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
@@ -1125,23 +1028,39 @@ You will be notified automatically of any progress on your issue.
 This is open source software.  The code repository is available for
 public review and contribution under the terms of the license.
 
-L<https://github.com/shantanubhadoria/perl-printer-thermal>
+L<https://github.com/shantanubhadoria/printer-thermal>
 
-  git clone git://github.com/shantanubhadoria/perl-printer-thermal.git
+  git clone git://github.com/shantanubhadoria/printer-thermal.git
 
 =head1 AUTHOR
 
-Shantanu Bhadoria (shantanu@cpan.org)
+Shantanu Bhadoria <shantanu at cpan dott org>
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords Shantanu Bhadoria
+=over 4
 
-Shantanu Bhadoria <shantanu att cpan dott org>
+=item *
+
+Shantanu Bhadoria <shantanu dott bhadoria atttt cpan dott org>
+
+=item *
+
+Shantanu Bhadoria <shantanu.bhadoria@gmail.com>
+
+=item *
+
+Shantanu Bhadoria <shantanu@cpan.org>
+
+=item *
+
+Shantanu Bhadoria <shantanu@shantanu-M14xR2.(none)>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Shantanu Bhadoria.
+This software is copyright (c) 2013 by Shantanu Bhadoria.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
